@@ -6,6 +6,7 @@ from .depot.github import set_config as github_set_config
 from .depot.img_url import set_config as img_url_set_config
 from .depot.hua_ban import set_config as hua_ban_set_config
 from .depot.xywm import set_config as xywm_set_config
+from .depot.pomf_se import set_config as pomf_se_set_config
 
 
 class DepotConfig:
@@ -14,3 +15,4 @@ class DepotConfig:
     ImgUrl = img_url_set_config
     HuaBan = hua_ban_set_config
     Xywm = xywm_set_config
+    PomfSe = pomf_se_set_config
