@@ -11,6 +11,28 @@ class DepotType(Enum):
     
     url: https://catbox.moe/
     """
+    PomfSe = auto()
+    """
+    一类图床. 使用同一套框架运行, 上传接口一致. 
+        * 不同人维护的不同服务.
+        * 因此这里提供一个类型, 可配置上传连接 
+        * 此服务可靠性应该是不高
+    限制: 不同服务的限制不同
+    
+    配置: 
+        * 可以不修改配置
+        * 留出配置文件是为了防止所有服务都不能用了, 可以自定义上传接口
+    
+    可通过下方链接找到相似的站点,
+        * 链接: https://pomf.se/
+        * 上传参数: files[] (指定上传文件)
+        * 响应: {"success": true, "files": [{"url": "xxx"}]} 
+    
+    注意: 
+        * 默认配置的服务中存在会过期的图床, 使用时请确认
+    
+    url: https://pomf.se/
+    """
     PngCm = auto()
     """
     图床
